Welcome to Terbium Lab's Matchlight SDK!
========================================

Matchlight exists to quickly and privately alert its users when any of their
sensitive information appears for sale or vandalism out on the dark web. The
product is fully automated, and operates using Data Fingerprints — a one-way
representation that allows Terbium to monitor for client data without
needing to know what that data is.

Data fingerprints are generated by dividing any text (for example a personal
information record) into 14 character tiles — characters 1-14, characters
15-28, and so on. Each one of these tiles is then hashed using a standard
SHA-512 Hash, and the resulting collection of hashes makes up the data
fingerprint for that customer asset. That fingerprint — not the original
data — is sent to Terbium.

*Fingerprint Monitoring*

Fingerprint Monitoring is much like a fully private Google Alerts for the Dark
Web. Customers generate a one-way data fingerprint, which is the only
information submitted to Terbium. Terbium then monitors the dark web for the
appearance of identical data fingerprints, alerting customers to the appearance
of their information if and when it is posted. Customers may monitor for exact
strings that are 14 characters or greater in length. An alert
is generated when a set of fingerprints on the dark web matches a set
of fingerprints in a record.

*Retrospective Search*

Retrospective search is much like a fully private Google Search for the Dark
Web. Customers generate a one-way data fingerprint, which is the only
information submitted to Terbium. Terbium then searches its full historical
index of all fingerprints it has ever collected from the dark web, alerting
customers if their data was ever seen by Terbium’s web crawler. Customers
may search for exact strings that are 14 characters or greater in length.

*DataFeeds*

Data feeds provide forward looking monitoring for certain keywords or patterns.
Unlike Fingerprint Monitoring or Retrospective Search, Terbium does have
access to customer data under monitoring. Data feeds allow for substantial
extra flexibility by allowing for pattern matching, whereas Fingerprint
Monitoring and Search allow for exact string matching only. Customers may
monitor for keywords or patterns of any length.


.. toctree::
   :maxdepth: 2

   Getting Started <guide>
   API Documentation <api>
   Advanced Configuration <connection_obj>
